@@ -56,7 +56,7 @@
 #' @export
 visualize <- function(
   dataset, xvar, yvar = "", comby = FALSE, combx = FALSE,
-  type = ifelse(is_empty(yvar), "dist", "scatter"), nrobs = -1,
+  type = ifelse(radiant.data::is_empty(yvar), "dist", "scatter"), nrobs = -1,
   facet_row = ".", facet_col = ".", color = "none", fill = "none",
   size = "none", fillcol = "blue", linecol = "black", pointcol = "black",
   bins = 10, smooth = 1, fun = "mean", check = "", axes = "",
@@ -65,6 +65,15 @@ visualize <- function(
   shiny = FALSE, custom = FALSE, envir = parent.frame()
 ) {
 
+  if (missing(xvar) && type == "box") {
+    xvar <- yvar
+    type = "box-single"
+    if (comby) {
+      comby <- FALSE
+      combx <- TRUE
+    }
+  }
+
   ## inspired by Joe Cheng's ggplot2 browser app http://www.youtube.com/watch?feature=player_embedded&v=o2B5yJeEl1A#!
   vars <- xvar
 
@@ -82,7 +91,7 @@ visualize <- function(
     fun <- fun[1:3] ## only scatter can deal with multiple functions, max 3 for now
     message("No more than three functions (", paste(fun, collapse = ", "), ") can be used with scatter plots")
   }
-  if (!type %in% c("scatter", "box")) check %<>% sub("jitter", "", .)
+  if (!type %in% c("scatter", "box", "box-single")) check %<>% sub("jitter", "", .)
 
   ## variable to use if bar chart is specified
   byvar <- NULL
@@ -91,7 +100,7 @@ visualize <- function(
     if (!type %in% c("dist", "density")) {
       return("No Y-variable provided for a plot that requires one")
     }
-  } else if (type == "surface" && is_empty(fill, "none")) {
+  } else if (type == "surface" && radiant.data::is_empty(fill, "none")) {
     return("No Fill variable provided for a plot that requires one")
   } else {
     if (type %in% c("dist", "density")) {
@@ -130,7 +139,7 @@ visualize <- function(
   df_name <- if (is_string(dataset)) dataset else deparse(substitute(dataset))
   dataset <- get_data(dataset, vars, filt = data_filter, envir = envir)
 
-  if (type == "scatter" && !is_empty(nrobs)) {
+  if (type == "scatter" && !radiant.data::is_empty(nrobs)) {
     nrobs <- as.integer(nrobs)
     if (nrobs > 0 && nrobs < nrow(dataset)) {
       dataset <- sample_n(dataset, nrobs, replace = FALSE)
@@ -250,10 +259,10 @@ visualize <- function(
 
   ## combining Y-variables if needed
   if (comby && length(yvar) > 1) {
-    if (any(xvar %in% yvar)) return("X-variables cannot be part of Y-variables when combining Y-variables")
-    if (!is_empty(color, "none")) return("Cannot use Color when combining Y-variables")
-    if (!is_empty(fill, "none")) return("Cannot use Fill when combining Y-variables")
-    if (!is_empty(size, "none")) return("Cannot use Size when combining Y-variables")
+    if (any(xvar %in% yvar) && type != "box-single") return("X-variables cannot be part of Y-variables when combining Y-variables")
+    if (!radiant.data::is_empty(color, "none")) return("Cannot use Color when combining Y-variables")
+    if (!radiant.data::is_empty(fill, "none")) return("Cannot use Fill when combining Y-variables")
+    if (!radiant.data::is_empty(size, "none")) return("Cannot use Size when combining Y-variables")
     if (facet_row %in% yvar || facet_col %in% yvar) return("Facet row or column variables cannot be part of\nY-variables when combining Y-variables")
 
     dataset <- gather(dataset, "yvar", "values", !! yvar, factor_key = TRUE)
@@ -266,7 +275,7 @@ visualize <- function(
 
   ## combining X-variables if needed
   if (combx && length(xvar) > 1) {
-    if (!is_empty(fill, "none")) return("Cannot use Fill when combining X-variables")
+    if (!radiant.data::is_empty(fill, "none")) return("Cannot use Fill when combining X-variables")
     if (facet_row %in% xvar || facet_col %in% xvar) return("Facet row or column variables cannot be part of\nX-variables when combining Y-variables")
     if (any(!get_class(select_at(dataset, .vars = xvar)) %in% c("numeric", "integer"))) return("Cannot combine plots for non-numeric variables")
 
@@ -507,13 +516,22 @@ visualize <- function(
           summarise_all(fun)
         colnames(tmp)[ncol(tmp)] <- j
 
-        if ("sort" %in% axes && facet_row == "." && facet_col == ".") {
+        # if ("sort" %in% axes && facet_row == "." && facet_col == ".") {
+        if ("sort" %in% axes) {
+          print("got here")
+          tmp <- tmp %>% group_by_at(.vars = "clarity")
+ 
           if ("flip" %in% axes) {
-            tmp <- arrange_at(ungroup(tmp), .vars = j)
+            # tmp <- arrange_at(ungroup(tmp), .vars = j)
+            tmp <- arrange_at(tmp, .vars = j, .by_group = TRUE)
+            print(tmp)
           } else {
-            tmp <- arrange_at(ungroup(tmp), .vars = j, .funs = desc)
+            # tmp <- arrange_at(ungroup(tmp), .vars = j, .funs = desc)
+            tmp <- arrange_at(tmp, .vars = j, .funs = desc, .by_group = TRUE)
+            print(tmp)
           }
           tmp[[i]] %<>% factor(., levels = unique(.))
+          print(tmp)
         }
 
         plot_list[[itt]] <- ggplot(tmp, aes_string(x = i, y = j)) + {
@@ -567,8 +585,29 @@ visualize <- function(
         itt <- itt + 1
       }
     }
+  } else if (type == "box-single") {
+    itt <- 1
+    for (i in xvar) {
+        if (color == "none") {
+          plot_list[[itt]] <- dataset %>% ggplot(aes(x = "", y = .data[[i]])) +
+            geom_boxplot(alpha = alpha, fill = fillcol, outlier.color = pointcol, color = linecol) +
+            scale_x_discrete(labels = NULL, breaks = NULL) + labs(x = "")
+        } else {
+          plot_list[[itt]] <- dataset %>% ggplot(aes(x = "", y = .data[[i]], fill = color)) +
+            geom_boxplot(alpha = alpha)
+        }
+
+        if (!custom && (color == "none" || color == i)) {
+          plot_list[[itt]] <- plot_list[[itt]] + theme(legend.position = "none")
+        }
+
+        if ("log_y" %in% axes) plot_list[[itt]] <- plot_list[[itt]] + ylab(paste("log", i))
+
+        itt <- itt + 1
+    }
   }
 
+
   if (facet_row != "." || facet_col != ".") {
     facets <- if (facet_row == ".") {
       paste("~", facet_col)
@@ -578,7 +617,8 @@ visualize <- function(
     scl <- if ("scale_y" %in% axes) "free_y" else "fixed"
     facet_fun <- if (facet_row == ".") facet_wrap else facet_grid
     for (i in 1:length(plot_list))
-      plot_list[[i]] <- plot_list[[i]] + facet_fun(as.formula(facets), scales = scl)
+      # plot_list[[i]] <- plot_list[[i]] + facet_fun(as.formula(facets), scales = scl)
+      plot_list[[i]] <- plot_list[[i]] + facet_fun(as.formula(facets), scales = "free")
   }
 
   if (color != "none") {
@@ -680,7 +720,7 @@ qscatter <- function(dataset, xvar, yvar, lev = "", fun = "mean", bins = 20) {
     dataset <- mutate_at(dataset, .vars = yvar, .funs = as.factor)
   }
   if (is.factor(dataset[[yvar]])) {
-    if (is_empty(lev)) lev <- levels(pull(dataset, !! yvar))[1]
+    if (radiant.data::is_empty(lev)) lev <- levels(pull(dataset, !! yvar))[1]
     dataset <- mutate_at(dataset, .vars = yvar, .funs = function(y) as.integer(y == lev))
     lev <- paste0(" {", lev, "}")
   } else {
